CreateHintsOptions

Struct CreateHintsOptions 

pub struct CreateHintsOptions { /* private fields */ }
A builder for options for Client::create_hints_with_options.

Implementations

Source

impl CreateHintsOptions

pub fn new() -> Self

Creates a CreateHintsOptions with all default option values.

pub fn slot(self, slot: u32) -> Self

Sets the slot number for which the hints should be created. This is the slot whose world contains the locations being hinted.

By default, this is the current player’s slot

pub fn status(self, status: HintStatus) -> Self

Sets the status for the newly-created hint.

By default, this is HintStatus::Unspecified.