pub enum UpdatedField {
ServerTags(UstrSet),
Permissions {
release: Permission,
collect: Permission,
remaining: Permission,
},
HintEconomy {
points_per_hint: u64,
hint_points_per_check: u64,
},
HintPoints(u64),
Players(Vec<Arc<Player>>),
CheckedLocations(Vec<Location>),
}Expand description
An enum that indicates exactly what in a Client was updated.
Variants
ServerTags(UstrSet)
[Client.server_tags] changed.
This contains the previous tags.
Permissions
[Client.release_permission], [Client.collect_permission], and/or [Client.remaining_permission] changed.
This contains the old values for each permission.
HintEconomy
[Client.points_per_hint] and/or [Client.hint_points_per_check] changed.
This contains the previous values for each field.
HintPoints(u64)
[Client.hint_points] has changed.
This contains the previous value for the field.
Players(Vec<Arc<Player>>)
One or more players’ aliases have changed.
This includes the previous Player structs. Use [Client.assert_player] to access the new ones.
CheckedLocations(Vec<Location>)
Additional locations have been checked, usually from a co-op player in the same slot.
This includes all newly-checked locations.