pub struct CreateHintsOptions { /* private fields */ }Expand description
A builder for options for Client::create_hints_with_options.
Implementations
Sourceimpl CreateHintsOptions
impl CreateHintsOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a CreateHintsOptions with all default option values.
Sourcepub fn slot(self, slot: u32) -> Self
pub fn slot(self, slot: u32) -> Self
Sets the slot number for which the hints should be created. This is the slot whose world contains the locations being hinted.
By default, this is the current player’s slot
Sourcepub fn status(self, status: HintStatus) -> Self
pub fn status(self, status: HintStatus) -> Self
Sets the status for the newly-created hint.
By default, this is HintStatus::Unspecified.